@@ -662,6 +662,7 @@ DEVICES = [
     "fvp-morello-android",
     "fvp-morello-busybox",
     "fvp-morello-oe",
+    "fvp-morello-ubuntu",
     "qemu-arm",
     "qemu-armv5",
     "qemu-armv7",
@@ -685,21 +686,26 @@ DEVICES = [
 TESTS = [
     "binder",
     "bionic",
+    "boringssl",
     "boot",
     "compartment",
     "device-tree",
     "dvfs",
+    "fwts",
     "kunit",
     "lldb",
+    "libjpeg-turbo",
+    "libpdfium",
+    "libpng",
     "logd",
+    "multicore",
     "ltp-fcntl-locktests",
     "ltp-fs_bind",
     "ltp-fs_perms_simple",
     "ltp-fsx",
     "ltp-nptl",
     "ltp-smoke",
-    "multicore",
-    "fwts",
+    "zlib",
 ]
 
 
