@@ -5,9 +5,7 @@ import argparse
 from tuxsuite.cli.version import __version__
 
 from tuxsuite.cli.build import setup_parser as build_parser
-from tuxsuite.cli.group import setup_parser as group_parser
 from tuxsuite.cli.plan import setup_parser as plan_parser
-from tuxsuite.cli.project import setup_parser as project_parser
 from tuxsuite.cli.test import setup_parser as test_parser
 
 
@@ -31,13 +29,6 @@ def setup_parser(group, project):
     build.required = True
     build_parser(build)
 
-    # "group"
-    group = root.add_parser("group", help="groups").add_subparsers(
-        dest="sub_sub_command", help="Sub commands"
-    )
-    group.required = True
-    group_parser(group)
-
     # "plan"
     plan = root.add_parser("plan", help="plans").add_subparsers(
         dest="sub_sub_command", help="Sub commands"
@@ -45,13 +36,6 @@ def setup_parser(group, project):
     plan.required = True
     plan_parser(plan)
 
-    # "project"
-    project = root.add_parser("project", help="projects").add_subparsers(
-        dest="sub_sub_command", help="Sub commands"
-    )
-    project.required = True
-    project_parser(project)
-
     # "test"
     test = root.add_parser("test", help="tests").add_subparsers(
         dest="sub_sub_command", help="Sub commands"
