@@ -262,10 +262,11 @@ class BuildSetConfig:
 
 
 class PlanConfig:
-    def __init__(self, name, description, filename):
+    def __init__(self, name, description, filename, job_name=None):
         self.name = name
         self.description = description
         self.filename = filename
+        self.job_name = job_name
         self.plan = []
         self.__load_config__()
 
@@ -293,6 +294,8 @@ class PlanConfig:
             self.description = config["description"]
 
         for cfg in config["jobs"]:
+            if self.job_name is not None and cfg.get("name") != self.job_name:
+                continue
             builds = []
             if "build" in cfg:
                 builds = [cfg["build"]]
